# Generated by Django 4.1.7 on 2023-03-17 14:22

from django.db import migrations, models

import bx_django_utils.translation


class Migration(migrations.Migration):
    dependencies = [
        ("test_app", "0004_translatedmodel_not_translated"),
    ]

    operations = [
        migrations.CreateModel(
            name="RawTranslatedModel",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("translated", models.JSONField()),
                ("translated_multiline", models.JSONField(blank=True, default=dict)),
                ("not_translated", models.TextField(default="A Default Value")),
            ],
            options={
                "db_table": "test_app_translatedmodel",
                "managed": False,
            },
        ),
        migrations.CreateModel(
            name="TranslatedSlugTestModel",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "translated",
                    bx_django_utils.translation.TranslationField(("de-de", "en-us", "es")),
                ),
                (
                    "translated_slug",
                    bx_django_utils.translation.TranslationSlugField(
                        ("de-de", "en-us", "es"), blank=True, unique=True
                    ),
                ),
            ],
        ),
        migrations.AlterField(
            model_name="translatedmodel",
            name="translated",
            field=bx_django_utils.translation.TranslationField(("de-de", "en-us", "es")),
        ),
        migrations.AlterField(
            model_name="translatedmodel",
            name="translated_multiline",
            field=bx_django_utils.translation.TranslationField(("de-de", "en-us", "es"), blank=True),
        ),
    ]
